@@ -216,7 +216,32 @@ class PD_input:
         print("Normalization done")
         self.input_file = input
 
-    def sum_peptides_for_proteins(self,input):
+    def protein_rollup(self,input_file,method='sum'):
+        channels = [col for col in input_file.columns if 'Abundance:' in col]
+        MPA=list([col for col in input_file.columns if 'Master Protein Accession' in col])
+        MPA=MPA[0]
+        if method == 'sum':
+            input_file = input_file.groupby([MPA]).sum()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        elif method == 'median':
+            input_file = input_file.groupby([MPA]).median()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        elif method == 'mean':
+            input_file = input_file.groupby([MPA]).mean()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        else:
+            print('Problem detected: no correct method set. Used default')
+            input_file = input_file.groupby([MPA]).sum()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        
+        return result
+
+
+    def sum_peptides_for_proteins(self,input_file):
         '''This function takes a peptide/PSM level DataFrame stored in self.input_file and performs Protein quantification rollup based
         on the sum of all corresponding peptides.
 
@@ -224,10 +249,10 @@ class PD_input:
         '''
         print('Calculate Protein quantifications from PSM')
         
-        channels = [col for col in input.columns if 'Abundance:' in col]
-        MPA=list([col for col in input.columns if 'Master Protein Accession' in col])
+        channels = [col for col in input_file.columns if 'Abundance:' in col]
+        MPA=list([col for col in input_file.columns if 'Master Protein Accession' in col])
         MPA=MPA[0]
-        PSM_grouped=input.groupby(by=[MPA])
+        PSM_grouped=input_file.groupby(by=[MPA])
         result={}
         for group in PSM_grouped.groups:
             temp=PSM_grouped.get_group(group)
@@ -279,11 +304,6 @@ class plain_text_input:
             self.modifications = self.input_columns[1]
             self.mpa = self.input_columns[0]
             
-    def filter_peptides(self):
-        input_file1 = self.input_file
-        input_file1 = input_file1[~input_file1['Master Protein Accessions'].str.contains(';',na=False)]
-        input_file1 = input_file1[input_file1['Contaminant']==False]
-        self.input_file = input_file1  
 
     def IT_adjustment(self):
         '''This function adjusts the input DataFrame stored in the class variable self.input_file for Ion injection times.
@@ -437,6 +457,31 @@ class plain_text_input:
         input[channels]=input[channels].divide(norm_factors, axis=1)
         print("Normalization done")
         self.input_file = input
+
+    def protein_rollup(self,input_file,method='sum'):
+        channels = self.abundances
+        MPA = self.mpa
+
+        if method == 'sum':
+            input_file = input_file.groupby([MPA]).sum()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        elif method == 'median':
+            input_file = input_file.groupby([MPA]).median()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        elif method == 'mean':
+            input_file = input_file.groupby([MPA]).mean()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        else:
+            print('Problem detected: no correct method set. Used default')
+            input_file = input_file.groupby([MPA]).sum()
+            input_file.index = input_file[MPA]
+            result = input_file[channels]
+        
+        return result
+
     def sum_peptides_for_proteins(self,input):
         '''This function takes a peptide/PSM level DataFrame stored in self.input_file and performs Protein quantification rollup based
         on the sum of all corresponding peptides.
